<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Customer;
use App\CustomerType;
use App\Common;
use App\CategoryMaster;
use App\Product;
use App\CustomerProduct;
use App\Location;
use App\CustomerLocation;
use App\ModeDetail;
use App\ParentMaster;
use App\CustomerParent;
use Auth;
use Excel;

class CustomerController extends Controller
{

	public function __construct()
    {
        $this->middleware('auth');
    }

	public function viewList()
	{
		$customer = Customer::all();
		return view('customer/list',compact('customer'));
	}

	public function create()
	{	
		$type 	  = CustomerType::where('is_active','=','Y')->get();
		$status   = Common::where('masterkeyword','=','STATUS')->get();
		$industry = Common::where('masterkeyword','=','INDUSTRY TYPE')->get();
		$delivery = Common::where('masterkeyword','=','DELIVERY TYPE')->get();
		$location = Location::where('is_active','=','Y')
							->orderBy('location')
							->get();
		$mode_dtls = ModeDetail::orderBy('mode_name')->get();
		$par_dtls = null;
		
		return view('customer/create',compact('type','industry','status','delivery','location','mode_dtls','par_dtls'));
	}

	public function store(Request $request)
	{	
		$insert = Customer::create([
									'name' 			   => $request->get('name'),
									'customer_type_id' => $request->get('type'),
									'address' 		   => $request->get('address'),
									'location' 		   => $request->get('place'),
									'contact_person'   => $request->get('cont_person'),
									'mobileno' 		   => $request->get('mob'),
									'email_id' 		   => $request->get('email'),
									'industry_type'    => $request->get('industry'),
									'credit_limit'     => $request->get('limit'),
									'credit_period'    => $request->get('period'),
									'status' 		   => $request->get('status'),
									'delivery_type_id' => $request->get('d_type'),
									'customercode'     => $request->get('code'),
									'mode_detail_id' => $request->get('mode'),
								]);

		///new mod multiple location for customer///
		/*$loc_id = [];	*/
		foreach ($request->get('location') as $key => $loc) {
			CustomerLocation::firstOrCreate(['customer_id' => $insert->id,'location_id' => $loc]);
			/*array_push($loc_id,$loc);*/
		}
		/*dd($loc_id);*/
		foreach ($request->get('parent') as $key => $parent) {
			CustomerParent::firstOrCreate(['customer_id' => $insert->id,'parent_id' => $parent]);
		}

		return redirect()->route('customer.list')->with(['message' => true]);
		
	}

	public function edit($id)
	{
		$customer 	  = Customer::find($id);
		$type 		  = CustomerType::where('is_active','=','Y')->get();
		$status 	  = Common::where('masterkeyword','=','STATUS')->get();
		$industry 	  = Common::where('masterkeyword','=','INDUSTRY TYPE')->get();
		$delivery 	  = Common::where('masterkeyword','=','DELIVERY TYPE')->get();
		$customer_loc = CustomerLocation::where('customer_id','=',$customer->id)->pluck('location_id')->toArray();
		$location 	  = Location::where('is_active','=','Y')
								->orderBy('location')
								->get();
		$mode_dtls = ModeDetail::orderBy('mode_name')->get();
		$par_dtls = ParentMaster::orderBy('name')->get();

		$customer_parent = CustomerParent::where('customer_id','=',$customer->id)->pluck('parent_id')->toArray();


		$par_dtls = ParentMaster::whereIn('id',$customer_parent)->get();

		return view('customer/edit',compact('customer','type','status','industry','delivery','customer_loc','location','mode_dtls','par_dtls','customer_parent'));
	}

	public function update(Request $request)
	{	
		$insert = Customer::where('id','=',$request->get('id'))
							->update([
									'name' 			   => $request->get('name'),
									'customer_type_id' => $request->get('type'),
									'address' 		   => $request->get('address'),
									'location' 		   => $request->get('place'),
									'contact_person'   => $request->get('cont_person'),
									'mobileno' 		   => $request->get('mob'),
									'email_id' 		   => $request->get('email'),
									'industry_type'    => $request->get('industry'),
									'credit_limit' 	   => $request->get('limit'),
									'credit_period'    => $request->get('period'),
									'status' 		   => $request->get('status'),
									'delivery_type_id' => $request->get('d_type'),
									'customercode'     => $request->get('code'),
									'mode_detail_id' => $request->get('mode'),
								]);

		///new mod multiple location for customer///

		$loc_id = [];	
		foreach ($request->get('location') as $key => $loc) {
			if($loc != null){
				CustomerLocation::firstOrCreate(['customer_id' => $request->get('id'),'location_id' => $loc]);
			}
			array_push($loc_id,$loc);
		}

		$parent_id = [];	
		foreach ($request->get('parent') as $key => $parent) {
			if($loc != null){
				CustomerParent::firstOrCreate(['customer_id' => $request->get('id'),'parent_id' => $parent]);
			}
			array_push($parent_id,$parent);
		}

		CustomerLocation::where('customer_id','=',$request->get('id'))
						->whereNotIn('location_id',$loc_id)	
						->delete();	

		CustomerParent::where('customer_id','=',$request->get('id'))
						->whereNotIn('parent_id',$parent_id)	
						->delete();
		$parent_master_inuse = ParentMaster::join('customer_parent','customer_parent.parent_id','=','parent_master.id')->pluck('parent_master.id');
		ParentMaster::whereNotIn('id',$parent_master_inuse)->delete();				
		
		return redirect()->route('customer.list')->with(['update' => true]);
	}

	public function mapIndex($id)
	{
        $categories = CategoryMaster::orderBy('category')->get();
        $products   = NULL;
        $customerId = $id; 
        $custPdct  = CustomerProduct::where('customer_id','=',$id)->pluck('product_id')->toArray();
        $selctCat  = NULL;
		return view('customer/map_product',compact('categories','products','customerId','custPdct','selctCat'));
	}
	public function mapShow(Request $request)
	{
        $custPdct  = CustomerProduct::where('customer_id','=',$request->get('customer_id'))
                                    ->pluck('product_id')->toArray(); 
        $customerId = $request->get('customer_id');  
        $categories = CategoryMaster::orderBy('category')->get();
        $products   = Product::where('category_id','=',$request->get('category'))
                             ->orderBy('name')->get();
        $selctCat   = $request->get('category');
		return view('customer/map_product',compact('categories','products','customerId','custPdct','selctCat'));
	}

	public function addProduct(Request $request)
	{
       $product = CustomerProduct::create(array('customer_id'  => $request->get('option'),
       	                                        'product_id'   => $request->get('option1')));

       return $product;
	}

	public function deleteProduct(Request $request)
	{
	   $product = CustomerProduct::where('customer_id','=',$request->get('option'))
	                             ->where('product_id','=',$request->get('option1'))->delete();
       return $product;	
	}

	public function newModeUpdate(Request $request)
	{
		$new_name = strtoupper(trim($request->get('new_mode')));
		$is_exist = ModeDetail::where('mode_name','=',$new_name)->count();
		if($is_exist) {
			return 0;
		} else {
			$mode_d =  ModeDetail::create([
				'mode_name' => $new_name,
				'entered_by' => Auth::user()->id
			]);

			return $mode_d->id;
		}
	}

	public function newParentUpdate(Request $request)
	{
		$new_name = strtoupper(trim($request->get('new_name')));
		$new_code = strtoupper(trim($request->get('new_code')));
		// $is_exist = ParentMaster::where('name','=',$new_name)
		// 						->count();
		$is_exist_code = ParentMaster::where('code','=',$new_code)
								->count();
		if($is_exist_code) {
			return 0;
		}
		// else if($is_exist) {
		// 	return 0;
		// }
		 else {
			$parent_d =  ParentMaster::create([
				'name' => $new_name,
				'code' => $new_code,
			]);

			return $parent_d->id;
		}
	}

	public function uploadData()
	{
		dd('NOT WORKING');
		$path = "kmd_cust12092020.xlsx";
		$data = Excel::load($path, function($reader) {
		})->get();
		
		foreach ($data as $value) {
			$customer_exist = Customer::where('name','=',strtoupper($value->customer_name))->count();
			if($customer_exist == 0) {
				$customer_type_id = $industry_id = $location_id = $parent_id = 0;
				$parent = ParentMaster::where('name','=',strtoupper($value->parent_master_name))->first();
				if($parent) {
					$parent_id = $parent->id;
				} else {
					$parent = ParentMaster::create([
						'name' => strtoupper($value->parent_master_name),
						'code' => $value->parent_code,
					]);
					$parent_id = $parent->id;
				}

				$location = Location::where('location','=',strtoupper($value->location))->first();
				if($location) {
					$location_id = $location->id;
				} else {
					$location = Location::create([
						'is_active' => 'Y',
						'location' => strtoupper($value->location),
					]);	
					$location_id = $location;
				}

				$customer_type = CustomerType::where('name','=',$value->customer_type)->first();
				if($customer_type) {
					$customer_type_id = $customer_type->id;
				} else {
					$customer_type = CustomerType::create([
						'name' => strtoupper($value->customer_type),
						'is_active' => 'Y'
					]); 
					$customer_type_id = $customer_type->id; 
				}
				
				$industry = Common::where('masterkeyword','=','INDUSTRY TYPE')->where('name','=',strtoupper($value->industry_type))->first();
				if($industry) {
					$industry_id = $industry->id; 
				} else {
					$industry = Common::create([
						'name' => strtoupper($value->industry_type),
						'masterkeyword' => 'INDUSTRY TYPE',
						'parent_id' => 1
					]);
					$industry_id = $industry->id; 
				}
				if($customer_type_id && $industry_id && $location_id && $parent_id) {
					$customer = Customer::create([
						'name' 			   => strtoupper(trim($value->customer_name)),
						'customer_type_id' => $customer_type_id,
						'address' 		   => strtoupper(trim($value->location)),
						'location' 		   => strtoupper(trim($value->location)),
						'contact_person'   => strtoupper(trim($value->contact_person)),
						'mobileno' 		   => trim($value->contact_no),
						'industry_type'    => $industry_id,
						'status' 		   => 5,
						'customercode'     => strtoupper(trim($value->customer_code)),
						'mode_detail_id'   => 6,
						'parent_master_id' => $parent_id
					]);
					///new mod multiple location for customer///
					CustomerLocation::firstOrCreate(['customer_id' => $customer->id,'location_id' => $location_id]);		
				}	
			}

			
		}
	}


}