<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Supplier;
use App\SupplierProduct;
use App\SupplierRateEntry;
use App\Common;
use App\RateEntryLog;
use App\ProductUnit;
use App\SupplierUnitRate;

class SupplierRateEntryController extends Controller
{
	public function index()
	{
		$active = Common::where('name','=','ACTIVE')->first();
		
		$suppliers = Supplier::where('status_id','=',$active->id)->orderBy('name')->get();
		return view('rateentry/supplier_list',compact('suppliers'));
	} 

	public function create($id)
	{	
		$prev = [];
		$u_prev = [];
		$supplier = Supplier::find($id);
		$supplier_products = SupplierProduct::where('supplier_id','=',$id)->get();
	
		$today_products_price = SupplierRateEntry::where('supplier_id','=',$id)
												->where('cur_date','=',date('Y-m-d'))
												->where('is_active','=','Y')
												->get();

		foreach($supplier_products as $prd){
			$current = SupplierRateEntry::where('supplier_product_id','=',$prd->id)
												->where('cur_date','=',date('Y-m-d'))
												->where('is_active','=','Y');

			$count = $current->count();
			if($count < 1){
				$check = SupplierRateEntry::where('supplier_product_id','=',$prd->id)
											->where('is_active','=','Y');
				$curr_price[$prd->id] = null;
				$curr_unit[$prd->id] = null;
				$curr_cash[$prd->id] = null;
			}
			else{
				$check = SupplierRateEntry::where('supplier_product_id','=',$prd->id)
											->where('is_active','=','N')
											->orderBy('cur_date','DESC');

				$curr_price[$prd->id] = $current->first()->price;
				$curr_unit[$prd->id] = $current->first()->unit_id;
				$curr_cash[$prd->id] = $current->first()->cash_price;
			}
			
									
			if( count($check->get()) > 0){
				$prev[$prd->id] = $check->first()->price;
				$u_prev[$prd->id] = $check->first()->unit->unit;
				$prev_cash[$prd->id] = $check->first()->cash_price;
			}
			else{
				$prev[$prd->id] = null;
				$u_prev[$prd->id] = null;
				$prev_cash[$prd->id] = null;
			}

		}


		return view('rateentry/rate_entry_form',compact('supplier_products','id','supplier','today_products_price','prev','u_prev','curr_price','curr_unit','prev_cash','curr_cash'));
	}

	

	
	public function store(Request $request)
	{	
		$sup_id = $request->get('sup_id');

		$supplier = Supplier::find($sup_id);
		
		$supplier_products = SupplierProduct::where('supplier_id','=',$sup_id)->get();

		foreach($supplier_products as $product) {

			if($request->get('price'.$product->id) != null || $request->get('cash_price'.$product->id) != null) {
				
				$today_rate = SupplierRateEntry::where('supplier_product_id','=',$product->id)
										->where('unit_id','=',$request->get('unit'.$product->id))
										->where('grade_id','=',$product->grade_id)
										->where('standard_id','=',$product->standard_id)
										->where('cur_date','=',date('Y-m-d'))
										->where('is_active','=','Y')
										->where('supplier_id','=',$sup_id)
										->first();
				$curent_rate = SupplierRateEntry::where('supplier_product_id','=',$product->id)
										->where('unit_id','=',$request->get('unit'.$product->id))
										->where('grade_id','=',$product->grade_id)
										->where('standard_id','=',$product->standard_id)
										->where('is_active','=','Y')
										->where('supplier_id','=',$sup_id)
										->first();
				$prvs_rate = SupplierRateEntry::where('supplier_product_id','=',$product->id)
										->where('unit_id','=',$request->get('unit'.$product->id))
										->where('grade_id','=',$product->grade_id)
										->where('standard_id','=',$product->standard_id)
										->where('is_active','=','N')
										->where('supplier_id','=',$sup_id)
										->orderBy('cur_date','DESC')
										->first();

				if(!$curent_rate) {
					$curent_rate = $prvs_rate;
				}

				if($curent_rate) {
					$price = $curent_rate->price;
					$cash_price = $curent_rate->cash_price;
				} else {
					$price = null;
					$cash_price = null;
				}
				
				if($today_rate) {
					
					SupplierRateEntry::where('supplier_product_id','=',$product->id)
									->where('supplier_id','=',$sup_id)
									->where('unit_id','=',$request->get('unit'.$product->id))
									->where('grade_id','=',$product->grade_id)
									->where('standard_id','=',$product->standard_id)
									->where('cur_date','!=',date('Y-m-d'))
									->update([
										'is_active' => 'N'
									]);

					SupplierRateEntry::where('supplier_product_id','=',$product->id)
									->where('unit_id','=',$request->get('unit'.$product->id))
									->where('grade_id','=',$product->grade_id)
									->where('standard_id','=',$product->standard_id)
									->where('cur_date','=',date('Y-m-d'))
									->where('is_active','=','Y')
									->where('supplier_id','=',$sup_id)
									->update([
										'price' => ($request->get('price'.$product->id) != null) ? $request->get('price'.$product->id) : $price,
										'cash_price' => ($request->get('cash_price'.$product->id) != null) ? $request->get('cash_price'.$product->id) : $cash_price
									]);

				} else {
					
					$date = SupplierRateEntry::where('supplier_product_id','=',$product->id)
								->where('supplier_id','=',$sup_id)
								->where('unit_id','=',$request->get('unit'.$product->id))
								->where('grade_id','=',$product->grade_id)
								->where('standard_id','=',$product->standard_id)
								->get();
					
					SupplierRateEntry::where('supplier_product_id','=',$product->id)
								->where('supplier_id','=',$sup_id)
								->where('unit_id','=',$request->get('unit'.$product->id))
								->where('grade_id','=',$product->grade_id)
								->where('standard_id','=',$product->standard_id)
								->update([
									'is_active' => 'N'
								]);
					
					
				 	SupplierRateEntry::create([
						'supplier_id' => $sup_id,
						'product_id' => $product->product_id,
						'cur_date' => date('Y-m-d'),
						'price' => ($request->get('price'.$product->id) != null) ? $request->get('price'.$product->id) : $price,
						'cash_price' => ($request->get('cash_price'.$product->id) != null) ? $request->get('cash_price'.$product->id) : $cash_price,
						'unit_id' => $request->get('unit'.$product->id),
						'currency_id' => $supplier->currency_type_id,
						'grade_id' => $product->grade_id,
						'standard_id' => $product->standard_id,
						'is_active' => 'Y',
						'supplier_product_id' => $product->id,
					]);
				}

				
			}
			
		}
		
		return redirect()->route('rate.entry.list')->with('success','Supplier Rate Saved!');
		
	}


	public function toIndex()
	{
		return redirect()->route('rate.entry.list')->with('success','Supplier Rate Saved!');
	}

	public function getUnits(Request $request)
	{
       $units = ProductUnit::join('unit_of_measurement','unit_of_measurement.id','=','product_unit.unit_id')
                           ->where('product_unit.product_id','=',$request->get('option'))
                           ->where('product_unit.is_active','=','Y')
                           ->where('product_unit.unit_id','!=',$request->get('unit'))
                           ->selectRaw('unit_of_measurement.*')->get();
       
       foreach($units as $unit){

       	$unit['unit_val'] = '';
       	$unit['sup_unt_rat_id'] = '';
       	
       	$obj = SupplierUnitRate::where('unit_id','=',$unit->id)
       	                       ->where('product_id','=',$request->get('option'))
                               ->where('supplier_id','=',$request->get('supplier'))
                               ->where('standard_id','=',$request->get('std'))
                               ->where('grade_id','=',$request->get('grd'))
                               ->first();
	        if(count($obj) > 0){
	        	$unit['unit_val'] = $obj->value;
	        	$unit['sup_unt_rat_id'] = $obj->id;
	        } 

       }                    
                                                   
       return $units;                    
	}

	public function insertPdtUnits(Request $request)
	{
		$units = ProductUnit::join('unit_of_measurement','unit_of_measurement.id','=','product_unit.unit_id')
                           ->where('product_unit.product_id','=',$request->get('product'))
                           ->where('product_unit.is_active','=','Y')
                           ->where('product_unit.unit_id','!=',$request->get('unit'))
                           ->selectRaw('unit_of_measurement.*')->get();

        SupplierUnitRate::where('supplier_id','=',$request->get('supplier')) 
                        ->where('product_id','=',$request->get('product'))
                        ->where('standard_id','=',$request->get('std'))
                        ->where('grade_id','=',$request->get('grd'))->delete();                  
        $i = 0;
        
        foreach($units as $unit){
            
            if($request->get('option')[$i] != NULL){
            	 SupplierUnitRate::create(['supplier_id'   => $request->get('supplier'),
	            	                       'product_id'    => $request->get('product'),
	            	                       'standard_id'   => $request->get('std'),
	            	                       'grade_id'      => $request->get('grd'),
	            	                       'unit_id'       => $unit->id,
	            	                       'value'         => $request->get('option')[$i] ]);
            }
           
            $i++;
        }  
                         
	}

	public function deleteItem(Request $request)
	{
		SupplierRateEntry::where('supplier_product_id','=',$request->get('option'))
		                 ->delete();
		$pdt = SupplierProduct::find($request->get('option'));
		SupplierUnitRate::where('supplier_id','=',$pdt->supplier_id)
		                ->where('product_id','=',$pdt->product_id)
		                ->where('standard_id','=',$pdt->standard_id)
		                ->where('grade_id','=',$pdt->grade_id)
		                ->where('unit_id','=',$pdt->unit_id)->delete();
		SupplierProduct::where('id','=',$request->get('option'))->delete();                
	}
	
	
}