<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\User;
use App\Customer;
use App\Role;
use App\CustomerType;
use App\UserType;
use App\UserRole;
use App\Common;
use App\CustomerLocation;
use App\Location;
use App\CustomerParent;
use App\ParentMaster;
use Auth;
class UserController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }

   public function index()
   {
     
     $users = User::orderBy('name')->get();

   	 return view('users/index',compact('users'));

   }

   public function create()
   {
     $active    = Common::where('name','=','ACTIVE')->first();
     $customers = Customer::where('status','=',$active->id)->orderBy('name')->get();
     $roles     = Role::orderBy('name')->get();
     $Types     = CustomerType::where('is_active','=','Y')->orderBy('name')->get();
     $location  = Location::all();

   	 return view('users/create',compact('customers','roles','Types','location'));
   }

   public function visibleType(Request $request)
   {
   	 $role = Role::where('id','=',$request->get('option'))
   	           ->where('multiple_type','=','Y')->count();
   	 return $role;
   }

   public function store(Request $request)
   {

      $name = User::where('username','=',$request->get('username'))->count();

          if($name > 0)
          {
            return redirect('user/index')->with('exist','true'); 
          }
   	 $user = User::create(array( 'name'         => $request->get('name'),
   	 	                           'username'     => $request->get('username'),
   	 	                           'password'     => Hash::make($request->get('password')),
   	 	                           'customer_id'  => $request->get('customer'),
                                 'location_id'  => $request->get('location'),
                                 'choose_cust'  => ($request->get('choose')) ? 'Y' : 'N',
                                 'is_active'    => ($request->get('Isactive')) ? 'A' : 'I',
                                 'parent_id'    => $request->get('parent_id')
                               ));

   	 if($request->get('customerType') != NULL)
   	 {
   	   $type = $request->get('customerType');

   	   foreach($type as $types)
   	   {
   	   	 UserType::create(array( 'user_id'           => $user->id,
       	                         'customer_type_id'  => $types ));
   	   }	
       
   	 }

     if($request->get('role') != NULL)
     {
       UserRole::create(array( 'user_id'  => $user->id,
                               'role_id'  => $request->get('role') ));
     }

     return redirect('user/index')->with('save','true');
   }

   public function edit($id)
   {
      $user       = User::find($id);
      $active     = Common::where('name','=','ACTIVE')->first();
      $customers = Customer::where('status','=',$active->id)->orderBy('name')->get();
      $roles     = Role::orderBy('name')->get();
      $Types     = CustomerType::where('is_active','=','Y')->orderBy('name')->get();
      $userType = UserType::where('user_id','=',$id)->pluck('customer_type_id')->toArray();
      $userRole  = UserRole::where('user_id','=',$id)->first();

      $customer_id = $user->customer_id;
      $location_id = CustomerLocation::where('customer_id','=',$customer_id)->pluck('location_id');
      $location    = Location::all();

      $customer_parents = CustomerParent::join('parent_master','parent_master.id','=','customer_parent.parent_id')
                          ->where('customer_parent.customer_id','=',$customer_id)
                          ->selectRaw('parent_master.id,parent_master.name,parent_master.code')->get();

      return view('users/edit',compact('user','customers','roles','Types','userType','userRole','location','customer_parents'));
   }

   public function update(Request $request)
   {
      if($request->get('password') != null){

          $user = User::where('id','=',$request->get('user_id'))
                  ->update(array( 'name'         => $request->get('name'),
                                  'username'     => $request->get('username'),
                                  'password'     => Hash::make($request->get('password')),
                                  'customer_id'  => $request->get('customer'),
                                  'location_id'  => $request->get('location'),
                                  'choose_cust'  => ($request->get('choose')) ? 'Y' : 'N',
                                  'is_active'    => ($request->get('Isactive')) ? 'A' : 'I',
                                  'parent_id'    => $request->get('parent_id')
                               ));
      }
      else
      {
        $user = User::where('id','=',$request->get('user_id'))
                  ->update(array( 'name'         => $request->get('name'),
                                  'username'     => $request->get('username'),
                                  'customer_id'  => $request->get('customer'),
                                  'location_id'  => $request->get('location'),
                                  'choose_cust'  => ($request->get('choose')) ? 'Y' : 'N',
                                  'is_active'    => ($request->get('Isactive')) ? 'A' : 'I',
                                  'parent_id'    => $request->get('parent_id')
                               ));
      }
      

     if($request->get('customerType') != NULL)
     {
       $type = $request->get('customerType');
       
       UserType::where('user_id','=',$request->get('user_id'))->delete();

       foreach($type as $types)
       {
         UserType::create(array( 'user_id'           => $request->get('user_id'),
                                 'customer_type_id'  => $types ));
       }  
       
     }

     if($request->get('role') != NULL)
     {
       UserRole::where('user_id','=',$request->get('user_id'))->delete();
       UserRole::create(array( 'user_id'  => $request->get('user_id'),
                               'role_id'  => $request->get('role') ));
     }

     return redirect('user/index')->with('Update','true');
   }
   
   public function customerList(Request $request)
   {
      $customer_id = $request->get('customer_id');
      $location_id = CustomerLocation::where('customer_id','=',$customer_id)->pluck('location_id');
      $location    = Location::whereIn('id',$location_id)->get();
      if($customer_id == null)
      {
        $location    = Location::all();
      }
      
      return $location;
   }

   public function customerParentList(Request $request)
   {
      $customer_id = $request->get('customer_id');
      $customer_parents = CustomerParent::join('parent_master','parent_master.id','=','customer_parent.parent_id')
                          ->where('customer_parent.customer_id','=',$customer_id)
                          ->selectRaw('parent_master.id,parent_master.name,parent_master.code')->get();
      return $customer_parents;
   }

}
