<?php

namespace App;

use Illuminate\Notifications\Notifiable;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'username', 'password','customer_id','role_id','choose_cust','is_active','location_id'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    public $timestamps = true;

    public function customer()
    {
        return $this->belongsTo('App\Customer', 'customer_id');
    }

    /*public function role()
    {
        return $this->belongsTo('App\Role', 'role_id');
    }*/

    public function roles()
    {
        return $this->belongsToMany(
            'App\Role','user_role', 'user_id'
        );
    }

     public function role()
    {
        return $this->roles->first();
    }

    public function userRole()
    {
        return $this->hasOne('App\UserRole','user_id');
    }

    public function materialRequest()
    {
        return $this->hasMany('App\MaterialRequisition','entered_by');
    }

    public function purchaseRequest()
    {
        return $this->hasMany('App\PurchaseRequest','entered_by');
    }

       /**
     * Check if user has a permission by its id
     * 
     * @param  integer $permissionId
     * 
     * @return bool
     */
    public function userpermission($permissionId)
    {
        $permissions = $this->role()->permissions->pluck('id')->all();
        return in_array($permissionId, $permissions);
    }

    public function userTypes()
    {
        return $this->hasMany('App\UserType','user_id');
    }
    public function location()
    {
        return $this->belongsTo('App\Location','location_id')->withDefault(['id' => 0,'location' => 'NOT MAPPED']);
    }

}
